## What is Modela.ai API?

Modela.ai is an automatic machine learning platform for Kubernetes. The modela.ai api is a set
of custom kuberentes resources in the area of data science and automatic machine learning. 
The API is implemented by the modela.ai platform which is closed source as the moment. 

For complete documentation on the modela.ai API, please visit our documentation at [www.modela.ai](https://www.modela.ai/).

## Installing Modela.ai

The modela.ai platform can be installed via an helm chart. For a complete installation procedure
please refer to the modela.ai documentation at [www.modela.ai](https://www.modela.ai/docs).

## Using Modela.ai

The Modela API specify a set of crds and services which are implemented by the modela.ai platform. 